==> haskell-bsb-http-chunked-0.0.0.4-172-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-bsb-http-chunked.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 bsb-http-chunked
version:              0.0.0.4
visibility:           public
id:                   bsb-http-chunked-0.0.0.4-alV2dFDXkxAzveFIsar8T
key:                  bsb-http-chunked-0.0.0.4-alV2dFDXkxAzveFIsar8T
license:              BSD-3-Clause
copyright:
    (c) 2010-2014 Simon Meier
    (c) 2010 Jasper Van der Jeugt
    (c) 2013-2015 Leon P Smith
    (c) 2018 Simon Jakobi

maintainer:           Simon Jakobi <simon.jakobi@gmail.com>
author:
    Jasper Van der Jeugt, Simon Meier, Leon P Smith, Simon Jakobi

stability:            Provisional
homepage:             http://github.com/sjakobi/bsb-http-chunked
synopsis:             Chunked HTTP transfer encoding for bytestring builders
description:
    This library contains functions for encoding [bytestring
    builders](http://hackage.haskell.org/package/bytestring/docs/Data-ByteString-Builder.html#t:Builder)
    for [chunked HTTP\/1.1 transfer](https://en.wikipedia.org/wiki/Chunked_transfer_encoding).

    This functionality was extracted from
    the [blaze-builder](http://hackage.haskell.org/package/blaze-builder)
    package.

category:             Data, Network
abi:                  3253e6358042ff180485bd2ca49e2536
exposed:              True
exposed-modules:      Data.ByteString.Builder.HTTP.Chunked
import-dirs:          /usr/lib/ghc-8.10.3/site-local/bsb-http-chunked-0.0.0.4
library-dirs:         /usr/lib/ghc-8.10.3/site-local/bsb-http-chunked-0.0.0.4
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/x86_64-linux-ghc-8.10.3/bsb-http-chunked-0.0.0.4
hs-libraries:         HSbsb-http-chunked-0.0.0.4-alV2dFDXkxAzveFIsar8T
depends:              base-4.14.1.0 bytestring-0.10.12.0
haddock-interfaces:
    /usr/share/doc/haskell-bsb-http-chunked/html/bsb-http-chunked.haddock

haddock-html:         /usr/share/doc/haskell-bsb-http-chunked/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-bsb-http-chunked-0.0.0.4-182-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-bsb-http-chunked.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 bsb-http-chunked
version:              0.0.0.4
visibility:           public
id:                   bsb-http-chunked-0.0.0.4-8BYtVjXL0BT5pcvrKcPi0z
key:                  bsb-http-chunked-0.0.0.4-8BYtVjXL0BT5pcvrKcPi0z
license:              BSD-3-Clause
copyright:
    (c) 2010-2014 Simon Meier
    (c) 2010 Jasper Van der Jeugt
    (c) 2013-2015 Leon P Smith
    (c) 2018 Simon Jakobi

maintainer:           Simon Jakobi <simon.jakobi@gmail.com>
author:
    Jasper Van der Jeugt, Simon Meier, Leon P Smith, Simon Jakobi

stability:            Provisional
homepage:             http://github.com/sjakobi/bsb-http-chunked
synopsis:             Chunked HTTP transfer encoding for bytestring builders
description:
    This library contains functions for encoding [bytestring
    builders](http://hackage.haskell.org/package/bytestring/docs/Data-ByteString-Builder.html#t:Builder)
    for [chunked HTTP\/1.1 transfer](https://en.wikipedia.org/wiki/Chunked_transfer_encoding).

    This functionality was extracted from
    the [blaze-builder](http://hackage.haskell.org/package/blaze-builder)
    package.

category:             Data, Network
abi:                  4d8fcf0b9b6950c786ea5214d77b45f7
exposed:              True
exposed-modules:      Data.ByteString.Builder.HTTP.Chunked
import-dirs:          /usr/lib/ghc-8.10.4/site-local/bsb-http-chunked-0.0.0.4
library-dirs:         /usr/lib/ghc-8.10.4/site-local/bsb-http-chunked-0.0.0.4
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/x86_64-linux-ghc-8.10.4/bsb-http-chunked-0.0.0.4
hs-libraries:         HSbsb-http-chunked-0.0.0.4-8BYtVjXL0BT5pcvrKcPi0z
depends:              base-4.14.1.0 bytestring-0.10.12.0
haddock-interfaces:
    /usr/share/doc/haskell-bsb-http-chunked/html/bsb-http-chunked.haddock

haddock-html:         /usr/share/doc/haskell-bsb-http-chunked/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
